def test_r():
    print("Test Seurat")
    # seurat_path = "/Users/christophebecavin/
    # Documents/testatlas/PAH_675093.rds"
    #
    # print(seurat_path)
    #
    #
    # # atlas_seurat.install_library()
    # rcode = f'readRDS("{seurat_path}")'
    # print(rcode)
    # seurat = robjects.r(rcode)
    # print(seurat)
